@@ -1,5 +1,5 @@
 package App::Notifier::Service;
-$App::Notifier::Service::VERSION = '0.0702';
+$App::Notifier::Service::VERSION = '0.0800';
 use 5.014;
 
 use Dancer2;
@@ -125,7 +125,7 @@ get '/notify' => sub {
 };
 
 get '/' => sub {
-    template 'index';
+    return "OK\n";
 };
 
 true;
@@ -145,7 +145,7 @@ notifying that an event (such as the finish of a task) occured.
 
 =head1 VERSION
 
-version 0.0702
+version 0.0800
 
 =head1 SYNOPSIS
 
@@ -267,14 +267,6 @@ L<https://metacpan.org/release/App-Notifier-Service>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/App-Notifier-Service>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -283,14 +275,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-Notifier-Service>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/App-Notifier-Service>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
